@@ -3,7 +3,7 @@ print.voronoi<-function(voronoi.obj)
   if(!inherits(voronoi.obj,"voronoi"))
     stop("voronoi.obj must be of class \"voronoi\"")
   cat("voronoi mosaic:\n")
-  cat("node: (x,y): neighbours (<0: dummy node)\n")
+  cat("nodes: (x,y): neighbours (<0: dummy node)\n")
   for (i in 1:length(voronoi.obj$x))
     {
       if(voronoi.obj$node[i]){
@@ -11,7 +11,7 @@ print.voronoi<-function(voronoi.obj)
         cat(":",voronoi.obj$n1[i],voronoi.obj$n2[i],voronoi.obj$n3[i],"\n",sep=" ")
       }
     }
-  cat("dummy node: (x,y)\n")
+  cat("dummy nodes: (x,y)\n")
   for (i in 1:length(voronoi.obj$dummy.x))
     {
       cat(i,": (",voronoi.obj$dummy.x[i],",",voronoi.obj$dummy.y[i],")\n",sep="")
