@@ -1,4 +1,4 @@
-summary.tri<-function(tri.obj,print=T)
+summary.tri<-function(tri.obj)
 {
   if(!inherits(tri.obj,"tri"))
     stop("tri.obj must be of class \"tri\"")
@@ -19,15 +19,12 @@ summary.tri<-function(tri.obj,print=T)
                  nb=as.integer(0),
                  nt=as.integer(0)
                  )
-  if(print)
-    {
-      cat("number of nodes:",tri.obj$n,"\n")
-      cat("number of arcs:",ans$na,"\n")
-      cat("number of boundary nodes:",ans$nb,"\n")
-      cat("number of triangles:",ans$nt,"\n")
-      cat("number of constraints:",tri.obj$nc,"\n")
-      invisible(list(n=tri.obj$n,na=ans$na,nb=ans$nb,nt=ans$nt,nc=tri.obj$nc))
-    }
-  else
-    list(n=tri.obj$n,na=ans$na,nb=ans$nb,nt=ans$nt,nc=tri.obj$nc)
+  ans<-list(n=tri.obj$n,
+            na=ans$na,
+            nb=ans$nb,
+            nt=ans$nt,
+            nc=tri.obj$nc,
+            call=tri.obj$call)
+  class(ans)<-"summary.tri"
+  ans
 }
